@@ -7,7 +7,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw( rename );
 
-our $VERSION = '1.90_4';
+our $VERSION = '1.90_5';
 
 sub import {
     my $pack = shift;
@@ -160,8 +160,21 @@ File::Rename - Perl extension for renaming multiple files
   use File::Rename;
   File::Rename::rename \@ARGV, '$_ = lc';
 
+  use File::Rename qw(:config no_require_order);
+
 =head1 DESCRIPTION
 
+=head2 USE OPTINS
+
+Parameters to C<use File::Rename> consists of
+functions to be imported and configuration options.
+
+The only exported function is C<rename()>.  The
+configuation options are preceded by :config,
+and are passed to File::Rename::Options.
+
+=head2 FUNCTIONS
+
 =over 4
 
 =item C<rename( FILES, CODE [, VERBOSE])>
@@ -266,7 +279,7 @@ Encoding for filenames, provided by B<-u>.
 
 =head2 EXPORT
 
-None by default.
+rename
 
 =head1 ENVIRONMENT
 
