@@ -97,6 +97,16 @@ File::Rename::Options - Option processing for File::Rename
 
 =head1 DESCRIPTION
 
+=head2 CONFIGUATION
+
+The parameters to C<use File::Rename::Options> are 
+configurations settings for Getopt::Long
+
+The default configuration is posix_default and no_ignore_case;
+other settings are added to this list.
+
+=head2 FUNCTIONS
+
 =over 4
 
 =item C<GetOptions()>
